==> oci-java-sdk-osmanagement-2.14.0-sources.jar: com/oracle/bmc/osmanagement/model/IsEligibleForInstallation.java <==
/**
 * Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.osmanagement.model;

/**
 * Indicates whether the update can be installed using OSMS.
 **/
@javax.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20190801")
@lombok.extern.slf4j.Slf4j
public enum IsEligibleForInstallation {
    Installable("INSTALLABLE"),
    NotInstallable("NOT_INSTALLABLE"),
    Unknown("UNKNOWN"),

    /**
     * This value is used if a service returns a value for this enum that is not recognized by this
     * version of the SDK.
     */
    UnknownEnumValue(null);

    private final String value;
    private static java.util.Map<String, IsEligibleForInstallation> map;

    static {
        map = new java.util.HashMap<>();
        for (IsEligibleForInstallation v : IsEligibleForInstallation.values()) {
            if (v != UnknownEnumValue) {
                map.put(v.getValue(), v);
            }
        }
    }

    IsEligibleForInstallation(String value) {
        this.value = value;
    }

    @com.fasterxml.jackson.annotation.JsonValue
    public String getValue() {
        return value;
    }

    @com.fasterxml.jackson.annotation.JsonCreator
    public static IsEligibleForInstallation create(String key) {
        if (map.containsKey(key)) {
            return map.get(key);
        }
        LOG.warn(
                "Received unknown value '{}' for enum 'IsEligibleForInstallation', returning UnknownEnumValue",
                key);
        return UnknownEnumValue;
    }
}

==> oci-java-sdk-osmanagement-2.36.1-sources.jar: com/oracle/bmc/osmanagement/model/IsEligibleForInstallation.java <==
/**
 * Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.osmanagement.model;

/**
 * Indicates whether the update can be installed using OSMS.
 **/
@javax.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20190801")
public enum IsEligibleForInstallation {
    Installable("INSTALLABLE"),
    NotInstallable("NOT_INSTALLABLE"),
    Unknown("UNKNOWN"),

    /**
     * This value is used if a service returns a value for this enum that is not recognized by this
     * version of the SDK.
     */
    UnknownEnumValue(null);

    private static final org.slf4j.Logger LOG =
            org.slf4j.LoggerFactory.getLogger(IsEligibleForInstallation.class);

    private final String value;
    private static java.util.Map<String, IsEligibleForInstallation> map;

    static {
        map = new java.util.HashMap<>();
        for (IsEligibleForInstallation v : IsEligibleForInstallation.values()) {
            if (v != UnknownEnumValue) {
                map.put(v.getValue(), v);
            }
        }
    }

    IsEligibleForInstallation(String value) {
        this.value = value;
    }

    @com.fasterxml.jackson.annotation.JsonValue
    public String getValue() {
        return value;
    }

    @com.fasterxml.jackson.annotation.JsonCreator
    public static IsEligibleForInstallation create(String key) {
        if (map.containsKey(key)) {
            return map.get(key);
        }
        LOG.warn(
                "Received unknown value '{}' for enum 'IsEligibleForInstallation', returning UnknownEnumValue",
                key);
        return UnknownEnumValue;
    }
}
